@@ -56,8 +56,9 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 "annotated.html",
-"classcl_1_1_image_g_l.html#a0d65fbe2960edcd3b2ba6f857d98b813",
-"functions_u.html"
+"classcl_1_1_image.html#af47b59a0b6626ba0dd855f826f31ad9b",
+"classcl_1_1_platform.html#a436c09964ac6314a3763f5c15fb92e7d",
+""
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
